#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef HAVE_ODBC
#undef HAVE_MYSQL
#undef HAVE_FIREBIRD
#undef HAVE_LDAP
#undef HAVE_MDB
#undef HAVE_ORACLE
#undef HAVE_PRIMEBASE
#undef HAVE_FREETDS
#undef HAVE_FREETDS_VER0_5X
#undef HAVE_FREETDS_VER0_6X
#undef HAVE_SYBASE
#undef HAVE_IBMDB2
#undef SYBASE_DEBUG
#undef HAVE_POSTGRES
#undef HAVE_CAMEL
#undef HAVE_SQLITE
#undef HAVE_XBASE
#undef GETTEXT_PACKAGE
#undef BONOBO_EXPLICIT_TRANSLATION_DOMAIN
